@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,16 +22,15 @@
 package com.openexchange.sso.action;
 
 import java.util.Locale;
-import java.util.Set;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.google.common.collect.ImmutableSet;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.exception.OXException;
+import com.openexchange.net.HostList;
 import com.openexchange.sso.SSOConstants;
 import com.openexchange.sso.services.SSOServiceRegistry;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
@@ -86,7 +85,7 @@ public final class GetAction implements AJAXActionService {
         }
     }
 
-    private static final Set<String> LOCAL_HOST = ImmutableSet.of("127.0.0.1", "localhost", "::1/128", "::1");
+    private static final HostList LOCAL_HOST = HostList.of("127.0.0.1", "localhost", "::1/128", "::1");
 
     private boolean isLocalHost(final String hostname) {
         return null != hostname && LOCAL_HOST.contains(hostname.toLowerCase(Locale.US));
